function [x] = solveLaplace1(coordinates,elements,dirichlet,neumann,f,g,uD)

%*** Assembly of stiffness matrix in linear complexity
nE = size(elements,1);
nC = size(coordinates,1);
x = zeros(nC,1);
I = zeros(9*nE,1);
J = zeros(9*nE,1);
A = zeros(9*nE,1);
for i = 1:nE
   nodes = elements(i,:);
   B = [1 1 1 ; coordinates(nodes,:)'];
   grad = B \ [0 0 ; 1 0 ; 0 1];
   idx = 9*(i-1)+1:9*i;
   tmp = [1;1;1]*nodes;
   I(idx) = reshape(tmp',9,1);
   J(idx) = reshape(tmp,9,1);
   A(idx) = det(B)/2*reshape(grad*grad',9,1);
end
A = sparse(I,J,A,nC,nC);

%*** Prescribe values at Dirichlet nodes
dirichlet = unique(dirichlet);
x(dirichlet) = feval(uD,coordinates(dirichlet,:));

%*** Assembly of right-hand side
b = -A*x;
for i = 1:size(elements,1)
    nodes = elements(i,:);
    sT = [1 1 1]*coordinates(nodes,:)/3;
    b(nodes) = b(nodes) + det([1 1 1 ; coordinates(nodes,:)'])*feval(f,sT)/6;
end
for i = 1:size(neumann,1)
    nodes = neumann(i,:);
    mE = [1 1]*coordinates(nodes,:)/2;
    b(nodes) = b(nodes) + norm([1 -1]*coordinates(nodes,:))*feval(g,mE)/2;
end

%*** Computation of P1-FEM approximation
freenodes = setdiff(1:nC, dirichlet);
x(freenodes) = A(freenodes,freenodes)\b(freenodes);
end
